@@ -7,7 +7,7 @@ $(document).ready(function() {
     $('.send_message_button').click(sendMessage);
 
     // show the first active chat and set its label to active
-    $('.message_list:first').show();
+    $('.message_list:first:hidden').show();
     $('.chat_names a:first').addClass('selected');
 
     // Scroll all of the active chats to the bottom of the conversation
@@ -80,7 +80,13 @@ function gotMessages(resp) {
         for (var index in chat.messages) {
             var message = chat.messages[index];
             var new_message_element = $( document.createElement('li'));
-            $(new_message_element).html(message.name + ': ' + message.message);
+            if (message.name == '') {
+                $(new_message_element).addClass('system_message');
+                $(new_message_element).html(message.message);
+            }
+            else {
+                $(new_message_element).html(message.name + ': ' + message.message);
+            }
             $(new_message_element).attr('id', 'message_' + message.pk);
             $(message_list).append(new_message_element);
             // Add a "new_message" class to the current chat session label
